@@ -38,7 +38,7 @@ module TZInfo
         c.timezone 'Antarctica/Mawson', -338, 5, 3773, 60, 'Mawson Station, Holme Bay'
         c.timezone 'Antarctica/Davis', -823, 12, 2339, 30, 'Davis Station, Vestfold Hills'
         c.timezone 'Antarctica/Casey', -3977, 60, 6631, 60, 'Casey Station, Bailey Peninsula'
-        c.timezone 'Antarctica/Vostok', -392, 5, 1069, 10, 'Vostok Station, S Magnetic Pole'
+        c.timezone 'Antarctica/Vostok', -392, 5, 1069, 10, 'Vostok Station, Lake Vostok'
         c.timezone 'Antarctica/DumontDUrville', -200, 3, 8401, 60, 'Dumont-d\'Urville Station, Terre Adelie'
         c.timezone 'Antarctica/Syowa', -124211, 1800, 3959, 100, 'Syowa Station, E Ongul I'
         c.timezone 'Antarctica/Macquarie', -109, 2, 3179, 20, 'Macquarie Island Station, Macquarie Island'
@@ -386,8 +386,8 @@ module TZInfo
       country 'ID', 'Indonesia' do |c|
         c.timezone 'Asia/Jakarta', -37, 6, 534, 5, 'Java & Sumatra'
         c.timezone 'Asia/Pontianak', -1, 30, 328, 3, 'west & central Borneo'
-        c.timezone 'Asia/Makassar', -307, 60, 597, 5, 'east & south Borneo, Celebes, Bali, Nusa Tengarra, west Timor'
-        c.timezone 'Asia/Jayapura', -38, 15, 1407, 10, 'Irian Jaya & the Moluccas'
+        c.timezone 'Asia/Makassar', -307, 60, 597, 5, 'east & south Borneo, Sulawesi (Celebes), Bali, Nusa Tengarra, west Timor'
+        c.timezone 'Asia/Jayapura', -38, 15, 1407, 10, 'west New Guinea (Irian Jaya) & Malukus (Moluccas)'
       end
       country 'IE', 'Ireland' do |c|
         c.timezone 'Europe/Dublin', 160, 3, -25, 4
@@ -839,6 +839,7 @@ module TZInfo
         c.timezone 'America/Menominee', 40597, 900, -105137, 1200, 'Central Time - Michigan - Dickinson, Gogebic, Iron & Menominee Counties'
         c.timezone 'America/North_Dakota/Center', 169619, 3600, -121559, 1200, 'Central Time - North Dakota - Oliver County'
         c.timezone 'America/North_Dakota/New_Salem', 9369, 200, -121693, 1200, 'Central Time - North Dakota - Morton County (except Mandan area)'
+        c.timezone 'America/North_Dakota/Beulah', 56717, 1200, -916, 9, 'Central Time - North Dakota - Mercer County'
         c.timezone 'America/Denver', 47687, 1200, -125981, 1200, 'Mountain Time'
         c.timezone 'America/Boise', 157009, 3600, -46481, 400, 'Mountain Time - south Idaho & east Oregon'
         c.timezone 'America/Shiprock', 33107, 900, -391271, 3600, 'Mountain Time - Navajo'
@@ -846,9 +847,11 @@ module TZInfo
         c.timezone 'America/Los_Angeles', 30647, 900, -212837, 1800, 'Pacific Time'
         c.timezone 'America/Anchorage', 44077, 720, -539641, 3600, 'Alaska Time'
         c.timezone 'America/Juneau', 209887, 3600, -483911, 3600, 'Alaska Time - Alaska panhandle'
+        c.timezone 'America/Sitka', 41167, 720, -487087, 3600, 'Alaska Time - southeast Alaska panhandle'
         c.timezone 'America/Yakutat', 214369, 3600, -251509, 1800, 'Alaska Time - Alaska panhandle neck'
         c.timezone 'America/Nome', 58051, 900, -595463, 3600, 'Alaska Time - west Alaska'
         c.timezone 'America/Adak', 1297, 25, -635969, 3600, 'Aleutian Islands'
+        c.timezone 'America/Metlakatla', 198457, 3600, -18947, 144, 'Metlakatla Time - Annette Island'
         c.timezone 'Pacific/Honolulu', 15341, 720, -18943, 120, 'Hawaii'
       end
       country 'UY', 'Uruguay' do |c|
