@@ -157,6 +157,7 @@ module TZInfo
       linked_timezone 'America/Mendoza'
       timezone 'America/Menominee'
       timezone 'America/Merida'
+      timezone 'America/Metlakatla'
       timezone 'America/Mexico_City'
       timezone 'America/Miquelon'
       timezone 'America/Moncton'
@@ -169,6 +170,7 @@ module TZInfo
       timezone 'America/Nipigon'
       timezone 'America/Nome'
       timezone 'America/Noronha'
+      timezone 'America/North_Dakota/Beulah'
       timezone 'America/North_Dakota/Center'
       timezone 'America/North_Dakota/New_Salem'
       timezone 'America/Ojinaga'
@@ -195,6 +197,7 @@ module TZInfo
       timezone 'America/Sao_Paulo'
       timezone 'America/Scoresbysund'
       linked_timezone 'America/Shiprock'
+      timezone 'America/Sitka'
       linked_timezone 'America/St_Barthelemy'
       timezone 'America/St_Johns'
       timezone 'America/St_Kitts'
