@@ -1,13 +1,7 @@
 $:.unshift File.join(File.dirname(__FILE__), "..", "lib")
 require 'test/unit'
-require 'tzinfo/data_timezone'
-require 'tzinfo/linked_timezone'
-require 'tzinfo/time_or_datetime'
-require 'tzinfo/timezone'
-require 'tzinfo/timezone_offset_info'
-require 'tzinfo/timezone_period'
-require 'tzinfo/timezone_proxy'
-require 'tzinfo/timezone_transition_info'
+require File.join(File.dirname(__FILE__), 'test_utils')
+require 'tzinfo'
 
 include TZInfo
 
@@ -122,6 +116,27 @@ class TCTimezone < Test::Unit::TestCase
     assert_equal('../Invalid/Identifier', proxy.identifier)
   end
   
+  def test_get_tainted_loaded
+    Timezone.get('Europe/Andorra')
+  
+    safe_test do
+      tz = Timezone.get('Europe/Andorra'.taint)
+      assert_equal('Europe/Andorra', tz.identifier)
+    end
+  end
+  
+  # Disable test in Ruby 1.9. See:
+  # http://groups.google.com/group/ruby-talk-google/browse_thread/thread/170a7205555cedfc
+  # It doesn't appear to be possible to require a file from the load path in Ruby 1.9.
+  if RUBY_VERSION !~ /^1.9/
+    def test_get_tainted_not_loaded
+      safe_test do
+        tz = Timezone.get('Europe/Amsterdam'.taint)
+        assert_equal('Europe/Amsterdam', tz.identifier)
+      end
+    end
+  end
+  
   def test_new_no_args
     tz = Timezone.new
     
